<?php

/* utf8-marker = äöü
==========================================
CMSimple Plugin LoginLocker
Version loginlocker 2.8
Release: 2023-01-14
Idea: Gert Ebersbach http://www.ge-webdesign.de
Programming: Martin Damken http://www.zeichenkombinat.de
==========================================
License: GPL3 - no warranties
==========================================
*/

class CMSimpleLoginLock
{
    var $max_inactivity;
    var $warn_before = 20;
    var $pluginName  = 'loginlocker';
    var $lockFile    = '';
    var $token       = null;
    var $delay       = 300;

    function __construct($dir = null, $token = null)
    {
        include dirname(__FILE__) . DIRECTORY_SEPARATOR . 'config' . DIRECTORY_SEPARATOR . 'config.php';
        if (!$dir)
        {
            $dir = getcwd();
        }

        if ($token)
        {
            $this->token = $token;
        } else
        {
            $this->token = session_id();
        }

        $this->lockFile = $dir . '/content/.loginlock';

        if (!file_exists($this->lockFile))
        {
            touch($this->lockFile, time() - (int) ini_get('session.gc_maxlifetime'));
        }

        $this->max_inactivity = (int) $plugin_cf[$this->pluginName]['max_inactivity'] >= 30 ? (int) $plugin_cf[$this->pluginName]['max_inactivity'] : 30;

        if ($this->max_inactivity > (int) ini_get('session.gc_maxlifetime'))
        {
            $this->max_inactivity = (int) ini_get('session.gc_maxlifetime');
        }

        if (isset($plugin_cf[$this->pluginName]['warn_before']) && (int) $plugin_cf[$this->pluginName]['warn_before'] > 0 && $plugin_cf[$this->pluginName]['warn_before'] < $plugin_cf[$this->pluginName]['max_inactivity'])
        {
            $this->warn_before = $plugin_cf[$this->pluginName]['warn_before'];
        }

        if (isset($plugin_cf[$this->pluginName]['warn_before']) && (int) $plugin_cf[$this->pluginName]['warn_before'] > 0 && $plugin_cf[$this->pluginName]['warn_before'] < $plugin_cf[$this->pluginName]['max_inactivity'])
        {
            $this->warn_before = $plugin_cf[$this->pluginName]['warn_before'];
        }
    }

    function isLocked()
    {
        if (time() > filemtime($this->lockFile) + $this->max_inactivity + $this->delay)
        {
            return false;
        }
        return file_get_contents($this->lockFile) !== $this->token;
    }

    function hasExpired($adm)
    {
        if (!$adm)
        {
            return false;
        }

        if (time() <= filemtime($this->lockFile) + $this->max_inactivity)
        {
            return file_get_contents($this->lockFile) !== $this->token;
        }

        return file_get_contents($this->lockFile) === $this->token ;
    }

    function lock()
    {
        $fh = fopen($this->lockFile, 'w');
        if ($fh)
        {
            fwrite($fh, $this->token);
            fclose($fh);
            return;
        }
    }

    function unlock()
    {
        if (file_get_contents($this->lockFile) == $this->token)
        {
            touch($this->lockFile, time() - $this->max_inactivity - $this->delay);
        }
    }

    function unlockWithoutDelay()
    {
        touch($this->lockFile, time() - $this->max_inactivity - 3600);
    }

    function logOut($save = false)
    {
        global $sn;

        setcookie('status' . str_replace('.','xc6oMd3Rs689',str_replace('index.php','',$sn)), '', time() - 3600);
        setcookie('status', '', time() - 3600, CMSIMPLE_ROOT);
        setcookie('passwd', '', time() - 3600);
        setcookie('mode', '', time() - 3600);

        $location = 'http://' . $_SERVER['SERVER_NAME'] . $sn . '?' . '&logged-out';
        if ($save)
        {
            $location .= '&logout';
        }
        header('Location: ' . $location);
        exit;
    }

    function error($message, $args = null)
    {
        global $o;
        $o .= '<p class="cmsimplecore_warning" style="text-align: center;">' . $this->translate($message, $args) . '</p>' . "\n";
    }

    function translate($message, $args = null)
    {
        global $plugin_tx;

        $message = isset($plugin_tx[$this->pluginName][$message]) ? $plugin_tx[$this->pluginName][$message] : '{' . $message . '}';

        if (is_array($args) && count($args) > 0)
        {
            array_unshift($args, $message);
            $message = call_user_func_array('sprintf', $args);
        }

        if (is_string($args) && strlen($args) > 0)
        {
            $message = sprintf($message, $args);
        }
        return $message;
    }
}

?>